=====
Usage
=====

See examples_ in `DiamondLightSource/diffcalc-core`_ repository.

 .. _examples: https://github.com/DiamondLightSource/diffcalc-core/tree/main/examples
 .. _`DiamondLightSource/diffcalc-core`: https://github.com/DiamondLightSource/diffcalc-core
